/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                          **** MATEMTICAS ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE MATEMTICAS
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_Mat.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_Mat.txt
/*         as como el archivo Excale09_2008_Alum_Mat.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_Mat.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_Mat.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_Mat.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $mageb05f   "R"       ="Escuela rural"
                       "UA"      ="Escuela urbana de alta marginacin"
                       "UB"      ="Escuela urbana de baja marginacin"
                       "NA"      ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ma1_h24F    0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale09_2008_Alum_Mat;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       sma_01             3
       sma_02             3
       sma_03             3
       sma_04             3
       sma_05             3
       sma_06             3
       sma_07             3
       sma_08             3
       sma_09             3
       sma_10             3
       sma_11             3
       sma_12             3
       sma_13             3
       sma_14             3
       sma_15             3
       sma_16             3
       sma_17             3
       sma_18             3
       sma_19             3
       sma_20             3
       sma_21             3
       sma_22             3
       sma_23             3
       sma_24             3
       smb_01             3
       smb_02             3
       smb_03             3
       smb_04             3
       smb_05             3
       smb_06             3
       smb_07             3
       smb_08             3
       smb_09             3
       smb_10             3
       smb_11             3
       smb_12             3
       smb_13             3
       smb_14             3
       smb_15             3
       smb_16             3
       smb_17             3
       smb_18             3
       smb_19             3
       smb_20             3
       smb_21             3
       smb_22             3
       smb_23             3
       smb_24             3
       smc_01             3
       smc_02             3
       smc_03             3
       smc_04             3
       smc_05             3
       smc_06             3
       smc_07             3
       smc_08             3
       smc_09             3
       smc_10             3
       smc_11             3
       smc_12             3
       smc_13             3
       smc_14             3
       smc_15             3
       smc_16             3
       smc_17             3
       smc_18             3
       smc_19             3
       smc_20             3
       smc_21             3
       smc_22             3
       smc_23             3
       smc_24             3
       smd_01             3
       smd_02             3
       smd_03             3
       smd_04             3
       smd_05             3
       smd_06             3
       smd_07             3
       smd_08             3
       smd_09             3
       smd_10             3
       smd_11             3
       smd_12             3
       smd_13             3
       smd_14             3
       smd_15             3
       smd_16             3
       smd_17             3
       smd_18             3
       smd_19             3
       smd_20             3
       smd_21             3
       smd_22             3
       smd_23             3
       smd_24             3
       sme_01             3
       sme_02             3
       sme_03             3
       sme_04             3
       sme_05             3
       sme_06             3
       sme_07             3
       sme_08             3
       sme_09             3
       sme_10             3
       sme_11             3
       sme_12             3
       sme_13             3
       sme_14             3
       sme_15             3
       sme_16             3
       sme_17             3
       sme_18             3
       sme_19             3
       sme_20             3
       sme_21             3
       sme_22             3
       sme_23             3
       sme_24             3
       smf_01             3
       smf_02             3
       smf_03             3
       smf_04             3
       smf_05             3
       smf_06             3
       smf_07             3
       smf_08             3
       smf_09             3
       smf_10             3
       smf_11             3
       smf_12             3
       smf_13             3
       smf_14             3
       smf_15             3
       smf_16             3
       smf_17             3
       smf_18             3
       smf_19             3
       smf_20             3
       smf_21             3
       smf_22             3
       smf_23             3
       smf_24             3
       smg_01             3
       smg_02             3
       smg_03             3
       smg_04             3
       smg_05             3
       smg_06             3
       smg_07             3
       smg_08             3
       smg_09             3
       smg_10             3
       smg_11             3
       smg_12             3
       smg_13             3
       smg_14             3
       smg_15             3
       smg_16             3
       smg_17             3
       smg_18             3
       smg_19             3
       smg_20             3
       smg_21             3
       smg_22             3
       smg_23             3
       smg_24             3
       smh_01             3
       smh_02             3
       smh_03             3
       smh_04             3
       smh_05             3
       smh_06             3
       smh_07             3
       smh_08             3
       smh_09             3
       smh_10             3
       smh_11             3
       smh_12             3
       smh_13             3
       smh_14             3
       smh_15             3
       smh_16             3
       smh_17             3
       smh_18             3
       smh_19             3
       smh_20             3
       smh_21             3
       smh_22             3
       smh_23             3
       smh_24             3
       pv1mat             8
       pv2mat             8
       pv3mat             8
       pv4mat             8
       pv5mat             8
       matnvl1            3
       matnvl2            3
       matnvl3            3
       matnvl4            3
       matnvl5            3
       matnvlb1           3
       matnvlb2           3
       matnvlb3           3
       matnvlb4           3
       matnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1226;
   INPUT
       NACIONAL          1 - 1
       ESCUELA           2 - 5
       ID_ENT            6 - 7
       NOM_ENT           8 - 26
       ID_MOD           27 - 27
       MOD              28 - 31
       MAGEB05          32 - 33
       ESTRATO          34 - 40
       ENTEST           41 - 46
       ALUMNO           47 - 52
       ID_INSTR         53 - 68
       SEXO             69 - 69
       EDAD             70 - 80
       EDADC            81 - 81
       EDADN            82 - 82
       EDAD_AC          83 - 84
       MES_NAC          85 - 86
       W_ALU            87 - 97
       DOCENTE          98 - 102
       SMA_01          103 - 103
       SMA_02          104 - 104
       SMA_03          105 - 105
       SMA_04          106 - 106
       SMA_05          107 - 107
       SMA_06          108 - 108
       SMA_07          109 - 109
       SMA_08          110 - 110
       SMA_09          111 - 111
       SMA_10          112 - 112
       SMA_11          113 - 113
       SMA_12          114 - 114
       SMA_13          115 - 115
       SMA_14          116 - 116
       SMA_15          117 - 117
       SMA_16          118 - 118
       SMA_17          119 - 119
       SMA_18          120 - 120
       SMA_19          121 - 121
       SMA_20          122 - 122
       SMA_21          123 - 123
       SMA_22          124 - 124
       SMA_23          125 - 125
       SMA_24          126 - 126
       SMB_01          127 - 127
       SMB_02          128 - 128
       SMB_03          129 - 129
       SMB_04          130 - 130
       SMB_05          131 - 131
       SMB_06          132 - 132
       SMB_07          133 - 133
       SMB_08          134 - 134
       SMB_09          135 - 135
       SMB_10          136 - 136
       SMB_11          137 - 137
       SMB_12          138 - 138
       SMB_13          139 - 139
       SMB_14          140 - 140
       SMB_15          141 - 141
       SMB_16          142 - 142
       SMB_17          143 - 143
       SMB_18          144 - 144
       SMB_19          145 - 145
       SMB_20          146 - 146
       SMB_21          147 - 147
       SMB_22          148 - 148
       SMB_23          149 - 149
       SMB_24          150 - 150
       SMC_01          151 - 151
       SMC_02          152 - 152
       SMC_03          153 - 153
       SMC_04          154 - 154
       SMC_05          155 - 155
       SMC_06          156 - 156
       SMC_07          157 - 157
       SMC_08          158 - 158
       SMC_09          159 - 159
       SMC_10          160 - 160
       SMC_11          161 - 161
       SMC_12          162 - 162
       SMC_13          163 - 163
       SMC_14          164 - 164
       SMC_15          165 - 165
       SMC_16          166 - 166
       SMC_17          167 - 167
       SMC_18          168 - 168
       SMC_19          169 - 169
       SMC_20          170 - 170
       SMC_21          171 - 171
       SMC_22          172 - 172
       SMC_23          173 - 173
       SMC_24          174 - 174
       SMD_01          175 - 175
       SMD_02          176 - 176
       SMD_03          177 - 177
       SMD_04          178 - 178
       SMD_05          179 - 179
       SMD_06          180 - 180
       SMD_07          181 - 181
       SMD_08          182 - 182
       SMD_09          183 - 183
       SMD_10          184 - 184
       SMD_11          185 - 185
       SMD_12          186 - 186
       SMD_13          187 - 187
       SMD_14          188 - 188
       SMD_15          189 - 189
       SMD_16          190 - 190
       SMD_17          191 - 191
       SMD_18          192 - 192
       SMD_19          193 - 193
       SMD_20          194 - 194
       SMD_21          195 - 195
       SMD_22          196 - 196
       SMD_23          197 - 197
       SMD_24          198 - 198
       SME_01          199 - 199
       SME_02          200 - 200
       SME_03          201 - 201
       SME_04          202 - 202
       SME_05          203 - 203
       SME_06          204 - 204
       SME_07          205 - 205
       SME_08          206 - 206
       SME_09          207 - 207
       SME_10          208 - 208
       SME_11          209 - 209
       SME_12          210 - 210
       SME_13          211 - 211
       SME_14          212 - 212
       SME_15          213 - 213
       SME_16          214 - 214
       SME_17          215 - 215
       SME_18          216 - 216
       SME_19          217 - 217
       SME_20          218 - 218
       SME_21          219 - 219
       SME_22          220 - 220
       SME_23          221 - 221
       SME_24          222 - 222
       SMF_01          223 - 223
       SMF_02          224 - 224
       SMF_03          225 - 225
       SMF_04          226 - 226
       SMF_05          227 - 227
       SMF_06          228 - 228
       SMF_07          229 - 229
       SMF_08          230 - 230
       SMF_09          231 - 231
       SMF_10          232 - 232
       SMF_11          233 - 233
       SMF_12          234 - 234
       SMF_13          235 - 235
       SMF_14          236 - 236
       SMF_15          237 - 237
       SMF_16          238 - 238
       SMF_17          239 - 239
       SMF_18          240 - 240
       SMF_19          241 - 241
       SMF_20          242 - 242
       SMF_21          243 - 243
       SMF_22          244 - 244
       SMF_23          245 - 245
       SMF_24          246 - 246
       SMG_01          247 - 247
       SMG_02          248 - 248
       SMG_03          249 - 249
       SMG_04          250 - 250
       SMG_05          251 - 251
       SMG_06          252 - 252
       SMG_07          253 - 253
       SMG_08          254 - 254
       SMG_09          255 - 255
       SMG_10          256 - 256
       SMG_11          257 - 257
       SMG_12          258 - 258
       SMG_13          259 - 259
       SMG_14          260 - 260
       SMG_15          261 - 261
       SMG_16          262 - 262
       SMG_17          263 - 263
       SMG_18          264 - 264
       SMG_19          265 - 265
       SMG_20          266 - 266
       SMG_21          267 - 267
       SMG_22          268 - 268
       SMG_23          269 - 269
       SMG_24          270 - 270
       SMH_01          271 - 271
       SMH_02          272 - 272
       SMH_03          273 - 273
       SMH_04          274 - 274
       SMH_05          275 - 275
       SMH_06          276 - 276
       SMH_07          277 - 277
       SMH_08          278 - 278
       SMH_09          279 - 279
       SMH_10          280 - 280
       SMH_11          281 - 281
       SMH_12          282 - 282
       SMH_13          283 - 283
       SMH_14          284 - 284
       SMH_15          285 - 285
       SMH_16          286 - 286
       SMH_17          287 - 287
       SMH_18          288 - 288
       SMH_19          289 - 289
       SMH_20          290 - 290
       SMH_21          291 - 291
       SMH_22          292 - 292
       SMH_23          293 - 293
       SMH_24          294 - 294
       PV1MAT          295 - 302
       PV2MAT          303 - 310
       PV3MAT          311 - 318
       PV4MAT          319 - 326
       PV5MAT          327 - 334
       MATNVL1         335 - 335
       MATNVL2         336 - 336
       MATNVL3         337 - 337
       MATNVL4         338 - 338
       MATNVL5         339 - 339
       MATNVLB1        340 - 340
       MATNVLB2        341 - 341
       MATNVLB3        342 - 342
       MATNVLB4        343 - 343
       MATNVLB5        344 - 344
       WVARSTRR        345 - 346
       W_FSTR1         347 - 357
       W_FSTR2         358 - 368
       W_FSTR3         369 - 379
       W_FSTR4         380 - 390
       W_FSTR5         391 - 401
       W_FSTR6         402 - 412
       W_FSTR7         413 - 423
       W_FSTR8         424 - 434
       W_FSTR9         435 - 445
       W_FSTR10        446 - 456
       W_FSTR11        457 - 467
       W_FSTR12        468 - 478
       W_FSTR13        479 - 489
       W_FSTR14        490 - 500
       W_FSTR15        501 - 511
       W_FSTR16        512 - 522
       W_FSTR17        523 - 533
       W_FSTR18        534 - 544
       W_FSTR19        545 - 555
       W_FSTR20        556 - 566
       W_FSTR21        567 - 577
       W_FSTR22        578 - 588
       W_FSTR23        589 - 599
       W_FSTR24        600 - 610
       W_FSTR25        611 - 621
       W_FSTR26        622 - 632
       W_FSTR27        633 - 643
       W_FSTR28        644 - 654
       W_FSTR29        655 - 665
       W_FSTR30        666 - 676
       W_FSTR31        677 - 687
       W_FSTR32        688 - 698
       W_FSTR33        699 - 709
       W_FSTR34        710 - 720
       W_FSTR35        721 - 731
       W_FSTR36        732 - 742
       W_FSTR37        743 - 753
       W_FSTR38        754 - 764
       W_FSTR39        765 - 775
       W_FSTR40        776 - 786
       W_FSTR41        787 - 797
       W_FSTR42        798 - 808
       W_FSTR43        809 - 819
       W_FSTR44        820 - 830
       W_FSTR45        831 - 841
       W_FSTR46        842 - 852
       W_FSTR47        853 - 863
       W_FSTR48        864 - 874
       W_FSTR49        875 - 885
       W_FSTR50        886 - 896
       W_FSTR51        897 - 907
       W_FSTR52        908 - 918
       W_FSTR53        919 - 929
       W_FSTR54        930 - 940
       W_FSTR55        941 - 951
       W_FSTR56        952 - 962
       W_FSTR57        963 - 973
       W_FSTR58        974 - 984
       W_FSTR59        985 - 995
       W_FSTR60        996 - 1006
       W_FSTR61       1007 - 1017
       W_FSTR62       1018 - 1028
       W_FSTR63       1029 - 1039
       W_FSTR64       1040 - 1050
       W_FSTR65       1051 - 1061
       W_FSTR66       1062 - 1072
       W_FSTR67       1073 - 1083
       W_FSTR68       1084 - 1094
       W_FSTR69       1095 - 1105
       W_FSTR70       1106 - 1116
       W_FSTR71       1117 - 1127
       W_FSTR72       1128 - 1138
       W_FSTR73       1139 - 1149
       W_FSTR74       1150 - 1160
       W_FSTR75       1161 - 1171
       W_FSTR76       1172 - 1182
       W_FSTR77       1183 - 1193
       W_FSTR78       1194 - 1204
       W_FSTR79       1205 - 1215
       W_FSTR80       1216 - 1226
 ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       sma_01      = "realizar sumas con transformacin a partir de sumandos que se han dado de manera desordenada"
       sma_02      = "Usar la propiedad de densidad de los decimales"
       sma_03      = "Resolver problemas que implican usar dos o ms operaciones, adicin y sustraccin y el uso de nmeros decimales hasta centsimos"
       sma_04      = "Realizar sustracciones en las que el minuendo y el sustraendo son nmeros decimales no enteros, y que implican ordenar los nmeros respecto al punto decimal y realizar desagrupamientos"
       sma_05      = "Identificar figuras simtricas respecto a una recta"
       sma_06      = "Reconocer que la suma de los ngulos interiores de un tringulo es 180"
       sma_07      = "Resolver problemas que implican dos o ms operaciones: adicin y multiplicacin"
       sma_08      = "Ordenar fracciones"
       sma_09      = "Resolver problemas de equivalencia de fracciones de hora expresadas con decimales a minutos"
       sma_10      = "Identificar de conjuntos de cantidades representados en tablas  aquellos que mantienen una relacin inversamente proporcional entre s"
       sma_11      = "Identificar el radio de un crculo"
       sma_12      = "Imaginar giros de slidos"
       sma_13      = "Realizar divisiones en las  que tanto el dividendo como el divisor son  nmeros decimales no enteros"
       sma_14      = "Resolver problemas que impliquen sumar dos fracciones con distinto denominador, no mltiplos el uno del otro"
       sma_15      = "Identificar las instrucciones para la construccin de un cuadriltero"
       sma_16      = "Aplicar propiedades de ngulo central e inscrito en una circunferencia"
       sma_17      = "Identificar el producto notable que corresponde con un polinomio o una multiplicacin"
       sma_18      = "Calcular el volumen de prismas"
       sma_19      = "Resolver cadenas de operaciones que implican usar la jerarqua de operaciones"
       sma_20      = "Identificar la funcin que modela una situacin dada"
       sma_21      = "Identificar la solucin de un sistema de ecuaciones en una representacin grfica"
       sma_22      = "Resolver problemas que impliquen identificar la expresin algebraica que modela una secuencia numrica"
       sma_23      = "Identificar la moda de un conjunto de nmeros"
       sma_24      = "Calcular e interpretar frecuencias absolutas y relativas"
       smb_01      = "Resolver problemas que implican ms de una operacin: multiplicacin, adicin y sustraccin de nmeros naturales"
       smb_02      = "Resolver problemas que involucran usar el concepto y clculo del  m.c.d."
       smb_03      = "Identificar operaciones y procedimientos que permiten resolver un problema, multiplicacin y adicin"
       smb_04      = "Conocer el significado de la raz cuadrada"
       smb_05      = "Conocer el algoritmo de la raz cuadrada"
       smb_06      = "Identificar grficas de cantidades que varan proporcionalmente"
       smb_07      = "Resolver problemas que impliquen dividir fracciones"
       smb_08      = "Identificar la representacin grfica de una suma de fracciones"
       smb_09      = "Traducir del lenguaje verbal al simblico nmeros decimales"
       smb_10      = "Ordenar un grupo de nmeros decimales y fraccionaros, positivos y negativos"
       smb_11      = "Resolver problemas que implican  multiplicacin y divisin con nmeros decimales"
       smb_12      = "Imaginar el resultado de girar slidos formados por conos y cilindros"
       smb_13      = "Identificar rectas que son perpendiculares entre s"
       smb_14      = "Identificar todas las aristas de un cubo"
       smb_15      = "Identificar diferencias entre slidos"
       smb_16      = "Identificar las instrucciones para trazar una paralela a una recta por un punto dado"
       smb_17      = "Identifica el poliedro que corresponde con un desarrollo plano"
       smb_18      = "Resolver problemas que implican la sustraccin de dos trminos semejantes"
       smb_19      = "Resolver problemas que impliquen identificar y sumar trminos semejantes"
       smb_20      = "Usar la jerarqua de operaciones y los parntesis para determinar el valor numrico de un polinomio"
       smb_21      = "Identificar la tabla de valores que corresponde con una funcin"
       smb_22      = "Resolver problemas que impliquen plantear y simplificar una ecuacin"
       smb_23      = "Resolver problemas que impliquen interpretar y completar  tablas"
       smb_24      = "Resolver problemas que implican usar estrategias de conteo"
       smc_01      = "Traducir al lenguaje algebraico situaciones que conducen a ecuaciones lineales sencillas de la forma a + x = b ax = b ax + b = c"
       smc_02      = "Resolver problemas que impliquen una multiplicacin con factores decimales no enteros."
       smc_03      = "Resolver problemas que implican dos operaciones: multiplicacin y divisin"
       smc_04      = "Resolver problemas que implican una divisin con dividendo y divisor decimal no entero"
       smc_05      = "Identificar la operacin representada con el modelo de reas"
       smc_06      = "Identificar la pirmide que corresponde con un desarrollo plano"
       smc_07      = "Calcular la medida de un cateto a partir de la medida de la hipotenusa y del otro cateto"
       smc_08      = "Encontrar la diferencia entre una fraccin propia o impropia y la unidad y comparar fracciones entre s"
       smc_09      = "Resolver problemas que ponen en juego su estimacin de suma de reas a partir de un grfico o que pueden resolverse utilizando las relaciones del teorema de Pitgoras"
       smc_10      = "Imaginar e identificar las caras de un slido formado por otros slidos"
       smc_11      = "Sumar nmeros negativos"
       smc_12      = "Resolver problemas que implican estimar un resultado al sumar nmeros decimales"
       smc_13      = "Leer nmeros naturales formados con ms de seis cifras, sin ceros intermedios"
       smc_14      = "Traducir del lenguaje simblico al verbal nmeros decimales"
       smc_15      = "Identificar las instrucciones para la construccin de la tangente a una circunferencia por un punto exterior a ella"
       smc_16      = "Reconocer los resultados de realizar dos reflexiones consecutivas respecto a dos rectas"
       smc_17      = "Calcular el rea de regiones formadas por la interseccin de crculos y cuadrados"
       smc_18      = "Resolver problemas que implican el uso de sistemas de ecuaciones lineales de 2 x 2"
       smc_19      = "Identificar de un conjunto de cadenas de operaciones la que corresponde con un valor determinado"
       smc_20      = "Resolver problemas que implican encontrar el nmero de un determinado lugar en una secuencia numrica"
       smc_21      = "Identificar la funcin que corresponde con los valores de una tabla"
       smc_22      = "Identificar la funcin que corresponde con una grfica"
       smc_23      = "Conocer el procedimiento para calcular el promedio de un conjunto de nmeros naturales"
       smc_24      = "Resolver problemas que implican calcular  la moda y la media aritmtica"
       smd_01      = "Resolver problemas que implican usar a la fraccin como razn"
       smd_02      = "Resolver problemas que implican ms de una operacin de adicin y sustraccin"
       smd_03      = "Realizar adiciones con sumandos decimales no enteros, en situaciones que implican ordenar los nmeros respecto al punto decimal y realizar transformaciones"
       smd_04      = "Aplicar la ley de los signos en una multiplicacin"
       smd_05      = "Resolver problemas que impliquen usar m.c.d. mltiplos y divisores"
       smd_06      = "Resolver problemas que impliquen dos operaciones: de adicin y multiplicacin"
       smd_07      = "Resolucin de problemas que impliquen la determinacin de un porciento, es decir, qu porcentaje representa una cantidad"
       smd_08      = "Multiplicar una fraccin mixta por una fraccin propia o impropia"
       smd_09      = "Resolucin de problemas que impliquen la aplicacin o clculo de un porcentaje"
       smd_10      = "Resolver problemas que impliquen calcular la raz cuadrada, hasta centsimos"
       smd_11      = "Identificar rectas que son paralelas entre s"
       smd_12      = "Resolver problemas que implican conocer qu es un vrtice"
       smd_13      = "Identificar las instrucciones para la construccin de polgonos regulares"
       smd_14      = "Identificar la figura simtrica respecto a un punto"
       smd_15      = "Identificar las instrucciones para la construccin de tringulos equilteros"
       smd_16      = "Calcular el rea total de slidos compuestos"
       smd_17      = "Resolver problemas que implican calcular el rea de partes de un crculo"
       smd_18      = "Desarrollar los productos notables"
       smd_19      = "Identificar la grfica de una ecuacin cuadrtica"
       smd_20      = "Identificar la grfica que corresponde con una funcin"
       smd_21      = "Resolver problemas que impliquen identificar expresiones algebraicas equivalentes despus de aplicar alguna regla de factorizacin"
       smd_22      = "Identificar la funcin que corresponde con una grfica"
       smd_23      = "Resolver problemas de variacin proporcional inversa"
       smd_24      = "Calcular el rea de un crculo a partir de su dimetro"
       sme_01      = "Realizar multiplicaciones de un factor de tres cifras por uno de dos cifras, en las que las multiplicaciones parciales implican agrupamientos"
       sme_02      = "Resolver problemas que impliquen calcular un promedio, que implique la divisin de nmeros negativos"
       sme_03      = "Multiplicar fracciones propias o impropias"
       sme_04      = "Realizar multiplicaciones de un nmero natural por un nmero decimal no entero en el que las multiplicaciones parciales implican agrupamientos"
       sme_05      = "Conocer el valor relativo de las cifras en un nmero"
       sme_06      = "Conocer el algoritmo de la raz cuadrada"
       sme_07      = "Resolver problemas que impliquen sumar dos fracciones con el mismo denominador y distinto numerador"
       sme_08      = "Resolver problemas que implican realizar un reparto proporcional"
       sme_09      = "Resolver problemas de proporcionalidad directa que impliquen usar una fraccin del valor unitario"
       sme_10      = "Comprender el significado y uso de la raz cuadrada"
       sme_11      = "Resolver problemas que impliquen sumar,  restar y comparar fracciones"
       sme_12      = "Calcular el permetro de una figura compuesta de semicircunferencias"
       sme_13      = "Determinar las secciones planas que se forman al cortar un cono"
       sme_14      = "Reconocer la equivalencia del rea de tringulos no semejantes que mantienen la misma base y altura"
       sme_15      = "Aplicar el teorema de Tales"
       sme_16      = "Reconocer las relaciones entre las medidas de los lados con que se puede construir un tringulo"
       sme_17      = "Identificar una de las alturas de un tringulo"
       sme_18      = "Identificar la tabla de valores que corresponden con una funcin"
       sme_19      = "Resolver ecuaciones de primer grado con una incgnita de la forma ax + bx + c = dx + ex + f"
       sme_20      = "Resolver problemas que impliquen identificar y restar  trminos semejantes"
       sme_21      = "Resolver problemas que impliquen la simplificacin de trminos semejantes"
       sme_22      = "Sustituir correctamente los valores de los parmetros en la frmula general de resolucin de ecuaciones"
       sme_23      = "Resolver problemas de variacin proporcional directa que implican identificar y comparar constantes de variacin proporcional que son nmeros no enteros"
       sme_24      = "Resolver problemas que implican utilizar la regla de la suma"
       smf_01      = "Escribir nmeros naturales formados con ms de seis cifras, sin ceros intermedios"
       smf_02      = "Ordenar de forma descendente fracciones con el mismo numerador pero con distinto denominador"
       smf_03      = "Leer nmeros naturales formados con ms de seis cifras, con ceros intermedios"
       smf_04      = "Conocer el significado de la potencia e identificar la que modela una situacin problemtica"
       smf_05      = "Identificar semejanzas entre slidos"
       smf_06      = "Identificar las vistas laterales y frontales de slidos"
       smf_07      = "Resolver problemas que implican una multiplicacin de una fraccin propia por una fraccin mixta"
       smf_08      = "Resolver problemas que impliquen multiplicar fracciones"
       smf_09      = "Leer y escribir nmeros, expresados mediante potencias de 10"
       smf_10      = "Resolver problemas de proporcionalidad directa"
       smf_11      = "Comparar nmeros decimales"
       smf_12      = "Resolver problemas que impliquen sumar o restar fracciones con denominadores no mltiplos"
       smf_13      = "Identificar caractersticas de poliedros despus de realizar un corte con un plano"
       smf_14      = "Aplicar propiedades de los ngulos inscritos en una semi circunferencia"
       smf_15      = "Resolver ecuaciones incompletas"
       smf_16      = "Identificar las caractersticas simtricas de figuras"
       smf_17      = "Resolver problemas que implican calcular razones trigonomtricas"
       smf_18      = "Calcular el rea total de slidos formados por cubos"
       smf_19      = "Conocer el mtodo de suma y resta para resolver sistemas de ecuaciones de 2 x 2"
       smf_20      = "Identificar un sistema de ecuaciones que modela una situacin"
       smf_21      = "Multiplicar binomios en contexto del modelo de reas"
       smf_22      = "Multiplicar binomios"
       smf_23      = "Evaluar la frecuencia absoluta de un evento dada una lista de resultados de un experimento aleatorio"
       smf_24      = "Identificar la tabla que corresponde con los datos que se presentan en una grfica de barras"
       smg_01      = "Resolver problemas que implican ms de una operacin de multiplicacin o de adicin y multiplicacin"
       smg_02      = "Escribir nmeros naturales formados con ms de seis cifras con ceros intermedios"
       smg_03      = "Resolver problemas que implican sumar o restas fracciones mixtas, con denominadores que son mltiplos de uno de ellos"
       smg_04      = "Resolver problemas que impliquen conocer los efectos de elevar a un exponente una base decimal"
       smg_05      = "Identificar la mediana de un conjunto de nmeros"
       smg_06      = "Resolucin de problemas que impliquen utilizar la regla del producto"
       smg_07      = "Calcular el permetro de rectngulos"
       smg_08      = "Resolver problemas que implican calcular el m.c.m"
       smg_09      = "Resolver problemas que impliquen restar dos fracciones con distinto denominador, no mltiplos el uno del otro"
       smg_10      = "Resolver problemas que implican saber a qu se le llama cara en un slido geomtrico"
       smg_11      = "Resolver problemas que implican identificar polgonos regulares"
       smg_12      = "Resolver problemas que impliquen dos o ms operaciones: adicin y sustraccin"
       smg_13      = "Realizar divisiones en el que el dividendo es un nmero decimales no enteros y el divisor es un nmero natural"
       smg_14      = "Resolver problemas que impliquen usar dos o ms operaciones: adicin y sustraccin"
       smg_15      = "Identificar fracciones equivalentes"
       smg_16      = "Identificar las instrucciones para la construccin de la tangente a una circunferencia por un punto sobre ella"
       smg_17      = "Calcular el rea lateral de slidos"
       smg_18      = "Determinar las secciones planas que se forman al cortar una pirmide"
       smg_19      = "Usar el mtodo de sustitucin para resolver sistemas de ecuaciones lineales de 2 x 2"
       smg_20      = "Identificar la grfica que corresponde a una funcin de la forma f(x) = ax"
       smg_21      = "Conocer el mtodo de igualacin para resolver sistemas de ecuaciones de 2 x 2"
       smg_22      = "Identificar el procedimiento para calcular el rea de un crculo a partir de su dimetro"
       smg_23      = "Identificar sistemas de ecuaciones lineales de 2 x 2 que no tienen solucin"
       smg_24      = "Reconocer instrucciones para la construccin de un crculo"
       smh_01      = "Realizar multiplicaciones cuyos factores son nmeros decimales no enteros y  en el que las  multiplicaciones parciales implican agrupamientos"
       smh_02      = "Realizar divisiones en las que el dividendo est formado por cinco cifras con ceros intermedios y el divisor es de dos cifras"
       smh_03      = "Realizar sustracciones que implican desagrupamientos"
       smh_04      = "Identificar conjuntos de nmeros que tienen relacin proporcional entre s"
       smh_05      = "Conocer el algoritmo de la potenciacin"
       smh_06      = "Identificar operaciones y procedimientos que permiten resolver un problema."
       smh_07      = "Resolver problemas con dos o ms operaciones: adicin, multiplicacin, sustraccin"
       smh_08      = "Resolver problemas con dos o ms operaciones: adicin y sustraccin, con decimales hasta milsimos"
       smh_09      = "Identificar el significado de una fraccin como parte de un todo"
       smh_10      = "Resolver problemas que impliquen usar criterios de divisibilidad"
       smh_11      = "Identificar todos los ejes de simetra de un cuadrado"
       smh_12      = "Identificar las medidas de una figura que fue sujeta a una escala"
       smh_13      = "Determinar las secciones planas que se forman al cortar un cubo"
       smh_14      = "Calcular el rea de trapecio rectngulo a partir de un diagrama que exige calcular sus medidas"
       smh_15      = "Identificar las instrucciones para trazar una perpendicular a un segmento por uno de sus extremos"
       smh_16      = "Expresar con un nmero irracional la medida de un cateto calculado a partir de la hipotenusa y del otro cateto"
       smh_17      = "Resolver problemas que implican identificar escalas entre figuras"
       smh_18      = "Resolucin de problemas que conduzcan al uso de ecuaciones de primer grado con una incgnita"
       smh_19      = "Identificar ecuaciones que no tienen solucin"
       smh_20      = "Resolver problemas que impliquen identificar la ecuacin que modela una situacin"
       smh_21      = "Resolver problemas que impliquen identificar la funcin que modele una tabla de valores"
       smh_22      = "Resolver problemas que implican el uso de ecuaciones cuadrticas"
       smh_23      = "Resolver problemas que implican comparar probabilidades"
       smh_24      = "Resolver problemas que implican expresar una probabilidad como fraccin"
       pv1mat      = "Primer valor plausible de Matemticas"
       pv2mat      = "Segundo valor plausible de Matemticas"
       pv3mat      = "Tercer valor plausible de Matemticas"
       pv4mat      = "Cuarto valor plausible de Matemticas"
       pv5mat      = "Quinto valor plausible de Matemticas"
       matnvl1     = "Nivel de logro en Matemticas. Asociado a PV1MAT. (Cuatro niveles)"
       matnvl2     = "Nivel de logro en Matemticas. Asociado a PV2MAT. (Cuatro niveles)"
       matnvl3     = "Nivel de logro en Matemticas. Asociado a PV3MAT. (Cuatro niveles)"
       matnvl4     = "Nivel de logro en Matemticas. Asociado a PV4MAT. (Cuatro niveles)"
       matnvl5     = "Nivel de logro en Matemticas. Asociado a PV5MAT. (Cuatro niveles)"
       matnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV1MAT."
       matnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV2MAT."
       matnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV3MAT."
       matnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV4MAT."
       matnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV5MAT."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       sma_01             ma1_h24F.
       sma_02             ma1_h24F.
       sma_03             ma1_h24F.
       sma_04             ma1_h24F.
       sma_05             ma1_h24F.
       sma_06             ma1_h24F.
       sma_07             ma1_h24F.
       sma_08             ma1_h24F.
       sma_09             ma1_h24F.
       sma_10             ma1_h24F.
       sma_11             ma1_h24F.
       sma_12             ma1_h24F.
       sma_13             ma1_h24F.
       sma_14             ma1_h24F.
       sma_15             ma1_h24F.
       sma_16             ma1_h24F.
       sma_17             ma1_h24F.
       sma_18             ma1_h24F.
       sma_19             ma1_h24F.
       sma_20             ma1_h24F.
       sma_21             ma1_h24F.
       sma_22             ma1_h24F.
       sma_23             ma1_h24F.
       sma_24             ma1_h24F.
       smb_01             ma1_h24F.
       smb_02             ma1_h24F.
       smb_03             ma1_h24F.
       smb_04             ma1_h24F.
       smb_05             ma1_h24F.
       smb_06             ma1_h24F.
       smb_07             ma1_h24F.
       smb_08             ma1_h24F.
       smb_09             ma1_h24F.
       smb_10             ma1_h24F.
       smb_11             ma1_h24F.
       smb_12             ma1_h24F.
       smb_13             ma1_h24F.
       smb_14             ma1_h24F.
       smb_15             ma1_h24F.
       smb_16             ma1_h24F.
       smb_17             ma1_h24F.
       smb_18             ma1_h24F.
       smb_19             ma1_h24F.
       smb_20             ma1_h24F.
       smb_21             ma1_h24F.
       smb_22             ma1_h24F.
       smb_23             ma1_h24F.
       smb_24             ma1_h24F.
       smc_01             ma1_h24F.
       smc_02             ma1_h24F.
       smc_03             ma1_h24F.
       smc_04             ma1_h24F.
       smc_05             ma1_h24F.
       smc_06             ma1_h24F.
       smc_07             ma1_h24F.
       smc_08             ma1_h24F.
       smc_09             ma1_h24F.
       smc_10             ma1_h24F.
       smc_11             ma1_h24F.
       smc_12             ma1_h24F.
       smc_13             ma1_h24F.
       smc_14             ma1_h24F.
       smc_15             ma1_h24F.
       smc_16             ma1_h24F.
       smc_17             ma1_h24F.
       smc_18             ma1_h24F.
       smc_19             ma1_h24F.
       smc_20             ma1_h24F.
       smc_21             ma1_h24F.
       smc_22             ma1_h24F.
       smc_23             ma1_h24F.
       smc_24             ma1_h24F.
       smd_01             ma1_h24F.
       smd_02             ma1_h24F.
       smd_03             ma1_h24F.
       smd_04             ma1_h24F.
       smd_05             ma1_h24F.
       smd_06             ma1_h24F.
       smd_07             ma1_h24F.
       smd_08             ma1_h24F.
       smd_09             ma1_h24F.
       smd_10             ma1_h24F.
       smd_11             ma1_h24F.
       smd_12             ma1_h24F.
       smd_13             ma1_h24F.
       smd_14             ma1_h24F.
       smd_15             ma1_h24F.
       smd_16             ma1_h24F.
       smd_17             ma1_h24F.
       smd_18             ma1_h24F.
       smd_19             ma1_h24F.
       smd_20             ma1_h24F.
       smd_21             ma1_h24F.
       smd_22             ma1_h24F.
       smd_23             ma1_h24F.
       smd_24             ma1_h24F.
       sme_01             ma1_h24F.
       sme_02             ma1_h24F.
       sme_03             ma1_h24F.
       sme_04             ma1_h24F.
       sme_05             ma1_h24F.
       sme_06             ma1_h24F.
       sme_07             ma1_h24F.
       sme_08             ma1_h24F.
       sme_09             ma1_h24F.
       sme_10             ma1_h24F.
       sme_11             ma1_h24F.
       sme_12             ma1_h24F.
       sme_13             ma1_h24F.
       sme_14             ma1_h24F.
       sme_15             ma1_h24F.
       sme_16             ma1_h24F.
       sme_17             ma1_h24F.
       sme_18             ma1_h24F.
       sme_19             ma1_h24F.
       sme_20             ma1_h24F.
       sme_21             ma1_h24F.
       sme_22             ma1_h24F.
       sme_23             ma1_h24F.
       sme_24             ma1_h24F.
       smf_01             ma1_h24F.
       smf_02             ma1_h24F.
       smf_03             ma1_h24F.
       smf_04             ma1_h24F.
       smf_05             ma1_h24F.
       smf_06             ma1_h24F.
       smf_07             ma1_h24F.
       smf_08             ma1_h24F.
       smf_09             ma1_h24F.
       smf_10             ma1_h24F.
       smf_11             ma1_h24F.
       smf_12             ma1_h24F.
       smf_13             ma1_h24F.
       smf_14             ma1_h24F.
       smf_15             ma1_h24F.
       smf_16             ma1_h24F.
       smf_17             ma1_h24F.
       smf_18             ma1_h24F.
       smf_19             ma1_h24F.
       smf_20             ma1_h24F.
       smf_21             ma1_h24F.
       smf_22             ma1_h24F.
       smf_23             ma1_h24F.
       smf_24             ma1_h24F.
       smg_01             ma1_h24F.
       smg_02             ma1_h24F.
       smg_03             ma1_h24F.
       smg_04             ma1_h24F.
       smg_05             ma1_h24F.
       smg_06             ma1_h24F.
       smg_07             ma1_h24F.
       smg_08             ma1_h24F.
       smg_09             ma1_h24F.
       smg_10             ma1_h24F.
       smg_11             ma1_h24F.
       smg_12             ma1_h24F.
       smg_13             ma1_h24F.
       smg_14             ma1_h24F.
       smg_15             ma1_h24F.
       smg_16             ma1_h24F.
       smg_17             ma1_h24F.
       smg_18             ma1_h24F.
       smg_19             ma1_h24F.
       smg_20             ma1_h24F.
       smg_21             ma1_h24F.
       smg_22             ma1_h24F.
       smg_23             ma1_h24F.
       smg_24             ma1_h24F.
       smh_01             ma1_h24F.
       smh_02             ma1_h24F.
       smh_03             ma1_h24F.
       smh_04             ma1_h24F.
       smh_05             ma1_h24F.
       smh_06             ma1_h24F.
       smh_07             ma1_h24F.
       smh_08             ma1_h24F.
       smh_09             ma1_h24F.
       smh_10             ma1_h24F.
       smh_11             ma1_h24F.
       smh_12             ma1_h24F.
       smh_13             ma1_h24F.
       smh_14             ma1_h24F.
       smh_15             ma1_h24F.
       smh_16             ma1_h24F.
       smh_17             ma1_h24F.
       smh_18             ma1_h24F.
       smh_19             ma1_h24F.
       smh_20             ma1_h24F.
       smh_21             ma1_h24F.
       smh_22             ma1_h24F.
       smh_23             ma1_h24F.
       smh_24             ma1_h24F.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(192)
                   sma_01 sma_02 sma_03 sma_04 sma_05 sma_06 sma_07 sma_08 sma_09 sma_10
                   sma_11 sma_12 sma_13 sma_14 sma_15 sma_16 sma_17 sma_18 sma_19 sma_20
                   sma_21 sma_22 sma_23 sma_24 smb_01 smb_02 smb_03 smb_04 smb_05 smb_06
                   smb_07 smb_08 smb_09 smb_10 smb_11 smb_12 smb_13 smb_14 smb_15 smb_16
                   smb_17 smb_18 smb_19 smb_20 smb_21 smb_22 smb_23 smb_24 smc_01 smc_02
                   smc_03 smc_04 smc_05 smc_06 smc_07 smc_08 smc_09 smc_10 smc_11 smc_12
                   smc_13 smc_14 smc_15 smc_16 smc_17 smc_18 smc_19 smc_20 smc_21 smc_22
                   smc_23 smc_24 smd_01 smd_02 smd_03 smd_04 smd_05 smd_06 smd_07 smd_08
                   smd_09 smd_10 smd_11 smd_12 smd_13 smd_14 smd_15 smd_16 smd_17 smd_18
                   smd_19 smd_20 smd_21 smd_22 smd_23 smd_24 sme_01 sme_02 sme_03 sme_04
                   sme_05 sme_06 sme_07 sme_08 sme_09 sme_10 sme_11 sme_12 sme_13 sme_14
                   sme_15 sme_16 sme_17 sme_18 sme_19 sme_20 sme_21 sme_22 sme_23 sme_24
                   smf_01 smf_02 smf_03 smf_04 smf_05 smf_06 smf_07 smf_08 smf_09 smf_10
                   smf_11 smf_12 smf_13 smf_14 smf_15 smf_16 smf_17 smf_18 smf_19 smf_20
                   smf_21 smf_22 smf_23 smf_24 smg_01 smg_02 smg_03 smg_04 smg_05 smg_06
                   smg_07 smg_08 smg_09 smg_10 smg_11 smg_12 smg_13 smg_14 smg_15 smg_16
                   smg_17 smg_18 smg_19 smg_20 smg_21 smg_22 smg_23 smg_24 smh_01 smh_02
                   smh_03 smh_04 smh_05 smh_06 smh_07 smh_08 smh_09 smh_10 smh_11 smh_12
                   smh_13 smh_14 smh_15 smh_16 smh_17 smh_18 smh_19 smh_20 smh_21 smh_22
                   smh_23 smh_24;
   DO  i=1 TO 192;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;


   drop i;
RUN;
